@@ -1,4 +1,4 @@
 library(testthat)
 library(helda)
 
-testthat::test_check("helda")
+test_check("helda")
